@@ -86,4 +86,8 @@ def main():
     input()
 
 if __name__ == '__main__':
-    main()
+    try:
+        main()
+    except KeyboardInterrupt:
+        print()
+        quit()
